@@ -50,14 +50,13 @@
 
 G_BEGIN_DECLS
 
-#define NA_ICONTEXT_TYPE                       ( na_icontext_get_type())
-#define NA_ICONTEXT( instance )                ( G_TYPE_CHECK_INSTANCE_CAST( instance, NA_ICONTEXT_TYPE, NAIContext ))
-#define NA_IS_ICONTEXT( instance )             ( G_TYPE_CHECK_INSTANCE_TYPE( instance, NA_ICONTEXT_TYPE ))
-#define NA_ICONTEXT_GET_INTERFACE( instance )  ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), NA_ICONTEXT_TYPE, NAIContextInterface ))
+#define NA_ICONTEXT_TYPE                      ( na_icontext_get_type())
+#define NA_ICONTEXT( instance )               ( G_TYPE_CHECK_INSTANCE_CAST( instance, NA_ICONTEXT_TYPE, NAIContext ))
+#define NA_IS_ICONTEXT( instance )            ( G_TYPE_CHECK_INSTANCE_TYPE( instance, NA_ICONTEXT_TYPE ))
+#define NA_ICONTEXT_GET_INTERFACE( instance ) ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), NA_ICONTEXT_TYPE, NAIContextInterface ))
 
-typedef struct _NAIContext                 NAIContext;
-
-typedef struct _NAIContextInterfacePrivate NAIContextInterfacePrivate;
+typedef struct _NAIContext                    NAIContext;
+typedef struct _NAIContextInterfacePrivate    NAIContextInterfacePrivate;
 
 /**
  * NAIContextInterface:
@@ -96,12 +95,14 @@ typedef struct {
 
 GType    na_icontext_get_type( void );
 
+gboolean na_icontext_are_equal       ( const NAIContext *a, const NAIContext *b );
 gboolean na_icontext_is_candidate    ( const NAIContext *context, guint target, GList *selection );
 gboolean na_icontext_is_valid        ( const NAIContext *context );
-gboolean na_icontext_is_all_mimetypes( const NAIContext *context );
 
+void     na_icontext_check_mimetypes ( const NAIContext *context );
+
+void     na_icontext_copy            ( NAIContext *context, const NAIContext *source );
 void     na_icontext_read_done       ( NAIContext *context );
-
 void     na_icontext_set_scheme      ( NAIContext *context, const gchar *scheme, gboolean selected );
 void     na_icontext_set_only_desktop( NAIContext *context, const gchar *desktop, gboolean selected );
 void     na_icontext_set_not_desktop ( NAIContext *context, const gchar *desktop, gboolean selected );
