@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,6 +32,8 @@
 #include <config.h>
 #endif
 
+#ifdef HAVE_GCONF
+
 #include <string.h>
 
 #include <api/na-core-utils.h>
@@ -39,12 +41,15 @@
 
 static void        dump_entry( GConfEntry *entry, void *user_data );
 static GConfValue *read_value( GConfClient *gconf, const gchar *path, gboolean use_schema, GConfValueType type );
+
+#ifndef NA_DISABLE_DEPRECATED
 static gboolean    sync_gconf( GConfClient *gconf, gchar **message );
+#endif /* NA_DISABLE_DEPRECATED */
 
 /**
  * na_gconf_utils_get_subdirs:
  * @gconf: a GConfClient instance.
- * @path: a full path to be readen.
+ * @path: a full path to be read.
  *
  * Returns: a list of full path subdirectories.
  *
@@ -114,7 +119,7 @@ na_gconf_utils_has_entry( GSList *entries, const gchar *entry )
 /**
  * na_gconf_utils_get_entries:
  * @gconf: a  GConfClient instance.
- * @path: a full path to be readen.
+ * @path: a full path to be read.
  *
  * Loads all the key=value pairs of the specified key.
  *
@@ -498,6 +503,7 @@ na_gconf_utils_read_string_list( GConfClient *gconf, const gchar *path )
 	return( list_strings );
 }
 
+#ifndef NA_DISABLE_DEPRECATED
 /**
  * na_gconf_utils_write_bool:
  * @gconf: a GConfClient instance.
@@ -507,12 +513,13 @@ na_gconf_utils_read_string_list( GConfClient *gconf, const gchar *path )
  *
  * Writes a boolean at the given @path.
  *
- * Returns: %TRUE if the writing has been successfull, %FALSE else.
+ * Returns: %TRUE if the writing has been successful, %FALSE else.
  *
  * If returned not NULL, the @message contains an error message.
  * It should be g_free() by the caller.
  *
  * Since: 2.30
+ * Deprecated: 3.1.0
  */
 gboolean
 na_gconf_utils_write_bool( GConfClient *gconf, const gchar *path, gboolean value, gchar **message )
@@ -544,12 +551,13 @@ na_gconf_utils_write_bool( GConfClient *gconf, const gchar *path, gboolean value
  *
  * Writes an integer at the given @path.
  *
- * Returns: %TRUE if the writing has been successfull, %FALSE else.
+ * Returns: %TRUE if the writing has been successful, %FALSE else.
  *
  * If returned not NULL, the @message contains an error message.
  * It should be g_free() by the caller.
  *
  * Since: 2.30
+ * Deprecated: 3.1.0
  */
 gboolean
 na_gconf_utils_write_int( GConfClient *gconf, const gchar *path, gint value, gchar **message )
@@ -581,12 +589,13 @@ na_gconf_utils_write_int( GConfClient *gconf, const gchar *path, gint value, gch
  *
  * Writes a string at the given @path.
  *
- * Returns: %TRUE if the writing has been successfull, %FALSE else.
+ * Returns: %TRUE if the writing has been successful, %FALSE else.
  *
  * If returned not NULL, the @message contains an error message.
  * It should be g_free() by the caller.
  *
  * Since: 2.30
+ * Deprecated: 3.1.0
  */
 gboolean
 na_gconf_utils_write_string( GConfClient *gconf, const gchar *path, const gchar *value, gchar **message )
@@ -618,12 +627,13 @@ na_gconf_utils_write_string( GConfClient *gconf, const gchar *path, const gchar
  *
  * Writes a list of strings at the given @path.
  *
- * Returns: %TRUE if the writing has been successfull, %FALSE else.
+ * Returns: %TRUE if the writing has been successful, %FALSE else.
  *
  * If returned not NULL, the @message contains an error message.
  * It should be g_free() by the caller.
  *
  * Since: 2.30
+ * Deprecated: 3.1.0
  */
 gboolean
 na_gconf_utils_write_string_list( GConfClient *gconf, const gchar *path, GSList *value, gchar **message )
@@ -659,9 +669,10 @@ na_gconf_utils_write_string_list( GConfClient *gconf, const gchar *path, GSList
  *
  * Removes an entry from user preferences.
  *
- * Returns: %TRUE if the operation was successfull, %FALSE else.
+ * Returns: %TRUE if the operation was successful, %FALSE else.
  *
  * Since: 2.30
+ * Deprecated: 3.1.0
  */
 gboolean
 na_gconf_utils_remove_entry( GConfClient *gconf, const gchar *path, gchar **message )
@@ -700,6 +711,7 @@ na_gconf_utils_remove_entry( GConfClient *gconf, const gchar *path, gchar **mess
  * string was not of the GConf form.
  *
  * Since: 2.30
+ * Deprecated: 3.1.0
  */
 GSList *
 na_gconf_utils_slist_from_string( const gchar *value )
@@ -735,6 +747,7 @@ na_gconf_utils_slist_from_string( const gchar *value )
  * allocated string which should be g_free() by the caller.
  *
  * Since: 2.30
+ * Deprecated: 3.1.0
  */
 gchar *
 na_gconf_utils_slist_to_string( GSList *slist )
@@ -756,6 +769,7 @@ na_gconf_utils_slist_to_string( GSList *slist )
 
 	return( g_string_free( str, FALSE ));
 }
+#endif /* NA_DISABLE_DEPRECATED */
 
 static GConfValue *
 read_value( GConfClient *gconf, const gchar *path, gboolean use_schema, GConfValueType type )
@@ -790,6 +804,7 @@ read_value( GConfClient *gconf, const gchar *path, gboolean use_schema, GConfVal
 	return( value );
 }
 
+#ifndef NA_DISABLE_DEPRECATED
 static gboolean
 sync_gconf( GConfClient *gconf, gchar **message )
 {
@@ -809,3 +824,6 @@ sync_gconf( GConfClient *gconf, gchar **message )
 
 	return( ret );
 }
+#endif /* NA_DISABLE_DEPRECATED */
+
+#endif /* HAVE_GCONF */
