@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -192,7 +192,7 @@ nadp_iio_provider_write_item( const NAIIOProvider *provider, const NAObjectItem
 
 /*
  * actually writes the item to the existing NadpDesktopFile
- * as we have choosen to take advantage of data factory management system
+ * as we have chosen to take advantage of data factory management system
  * we do not need to enumerate each and every elementary data
  *
  * As we want keep comments between through multiple updates, we cannot
@@ -483,7 +483,7 @@ nadp_writer_ifactory_provider_write_data(
 	static const gchar *thisfn = "nadp_writer_ifactory_provider_write_data";
 	NadpDesktopFile *ndf;
 	guint code;
-	NADataDef *def;
+	const NADataDef *def;
 	gchar *profile_id;
 	gchar *group_name;
 	gchar *str_value;
@@ -514,8 +514,8 @@ nadp_writer_ifactory_provider_write_data(
 
 			switch( def->type ){
 
-				case NAFD_TYPE_STRING:
-					str_value = na_data_boxed_get_as_string( boxed );
+				case NA_DATA_TYPE_STRING:
+					str_value = na_boxed_get_string( NA_BOXED( boxed ));
 
 					if( !strcmp( def->name, NAFO_DATA_PATH )){
 						parms = na_object_get_parameters( object );
@@ -529,25 +529,25 @@ nadp_writer_ifactory_provider_write_data(
 					g_free( str_value );
 					break;
 
-				case NAFD_TYPE_LOCALE_STRING:
-					str_value = na_data_boxed_get_as_string( boxed );
+				case NA_DATA_TYPE_LOCALE_STRING:
+					str_value = na_boxed_get_string( NA_BOXED( boxed ));
 					nadp_desktop_file_set_locale_string( ndf, group_name, def->desktop_entry, str_value );
 					g_free( str_value );
 					break;
 
-				case NAFD_TYPE_BOOLEAN:
-					bool_value = GPOINTER_TO_UINT( na_data_boxed_get_as_void( boxed ));
+				case NA_DATA_TYPE_BOOLEAN:
+					bool_value = GPOINTER_TO_UINT( na_boxed_get_as_void( NA_BOXED( boxed )));
 					nadp_desktop_file_set_boolean( ndf, group_name, def->desktop_entry, bool_value );
 					break;
 
-				case NAFD_TYPE_STRING_LIST:
-					slist_value = ( GSList * ) na_data_boxed_get_as_void( boxed );
+				case NA_DATA_TYPE_STRING_LIST:
+					slist_value = ( GSList * ) na_boxed_get_as_void( NA_BOXED( boxed ));
 					nadp_desktop_file_set_string_list( ndf, group_name, def->desktop_entry, slist_value );
 					na_core_utils_slist_free( slist_value );
 					break;
 
-				case NAFD_TYPE_UINT:
-					uint_value = GPOINTER_TO_UINT( na_data_boxed_get_as_void( boxed ));
+				case NA_DATA_TYPE_UINT:
+					uint_value = GPOINTER_TO_UINT( na_boxed_get_as_void( NA_BOXED( boxed )));
 					nadp_desktop_file_set_uint( ndf, group_name, def->desktop_entry, uint_value );
 					break;
 
@@ -583,9 +583,12 @@ write_done_write_subitems_list( NadpDesktopFile *ndp, NAObjectItem *item )
 	static const gchar *thisfn = "nadp_writer_write_done_write_subitems_list";
 	GSList *subitems;
 	GSList *profile_groups, *ip;
+	gchar *tmp;
 
 	subitems = na_object_get_items_slist( item );
-	na_core_utils_slist_dump( thisfn, subitems );
+	tmp = g_strdup_printf( "%s (written subitems)", thisfn );
+	na_core_utils_slist_dump( tmp, subitems );
+	g_free( tmp );
 
 	nadp_desktop_file_set_string_list(
 			ndp,
@@ -594,7 +597,9 @@ write_done_write_subitems_list( NadpDesktopFile *ndp, NAObjectItem *item )
 			subitems );
 
 	profile_groups = nadp_desktop_file_get_profiles( ndp );
-	na_core_utils_slist_dump( thisfn, profile_groups );
+	tmp = g_strdup_printf( "%s (existing profiles)", thisfn );
+	na_core_utils_slist_dump( tmp, profile_groups );
+	g_free( tmp );
 
 	for( ip = profile_groups ; ip ; ip = ip->next ){
 		if( na_core_utils_slist_count( subitems, ( const gchar * ) ip->data ) == 0 ){
