@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,13 +32,14 @@
 #include <config.h>
 #endif
 
-#include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
+#include <libintl.h>
 
 #include <api/na-object-api.h>
 #include <api/na-core-utils.h>
 
-#include "nact-gtk-utils.h"
+#include "base-keysyms.h"
+#include "base-gtk-utils.h"
 #include "nact-main-tab.h"
 #include "nact-match-list.h"
 
@@ -330,7 +331,9 @@ nact_match_list_on_selection_changed( BaseWindow *window, const gchar *tab_name,
 	data = ( MatchListStr * ) g_object_get_data( G_OBJECT( window ), tab_name );
 	g_return_if_fail( data != NULL );
 
-	context = nact_main_tab_get_context( NACT_MAIN_WINDOW( window ), &data->editable_item );
+	g_object_get( G_OBJECT( window ),
+			MAIN_PROP_CONTEXT, &context, MAIN_PROP_EDITABLE, &data->editable_item,
+			NULL );
 
 	enable_tab = ( context != NULL );
 	nact_main_tab_enable_page( NACT_MAIN_WINDOW( data->window ), data->tab_id, enable_tab );
@@ -351,10 +354,10 @@ nact_match_list_on_selection_changed( BaseWindow *window, const gchar *tab_name,
 	}
 
 	column = gtk_tree_view_get_column( data->listview, ITEM_COLUMN );
-	nact_gtk_utils_set_editable( GTK_OBJECT( column ), data->editable_item && data->editable_filter );
+	base_gtk_utils_set_editable( G_OBJECT( column ), data->editable_item && data->editable_filter );
 
-	nact_gtk_utils_set_editable( GTK_OBJECT( data->addbutton ), data->editable_item );
-	nact_gtk_utils_set_editable( GTK_OBJECT( data->removebutton ), data->editable_item );
+	base_gtk_utils_set_editable( G_OBJECT( data->addbutton ), data->editable_item );
+	base_gtk_utils_set_editable( G_OBJECT( data->removebutton ), data->editable_item );
 	gtk_widget_set_sensitive( data->removebutton, FALSE );
 
 	st_on_selection_change = FALSE;
@@ -469,7 +472,7 @@ on_filter_edited( GtkCellRendererText *renderer, const gchar *path_str, const gc
 
 	g_return_if_fail( data->editable_filter );
 
-	context = nact_main_tab_get_context( NACT_MAIN_WINDOW( data->window ), NULL );
+	g_object_get( G_OBJECT( data->window ), MAIN_PROP_CONTEXT, &context, NULL );
 	g_return_if_fail( NA_IS_ICONTEXT( context ));
 
 	model = gtk_tree_view_get_model( data->listview );
@@ -488,7 +491,7 @@ on_filter_edited( GtkCellRendererText *renderer, const gchar *path_str, const gc
 
 	if( count_filters( text, data ) >= 1 ){
 		dialog = gtk_message_dialog_new(
-				base_window_get_toplevel( BASE_WINDOW( data->window )),
+				base_window_get_gtk_toplevel( BASE_WINDOW( data->window )),
 				GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
 				_( "'%s' filter already exists in the list.\nPlease provide another one." ), text );
 		gtk_dialog_run( GTK_DIALOG( dialog ));
@@ -527,7 +530,7 @@ on_filter_edited( GtkCellRendererText *renderer, const gchar *path_str, const gc
 	na_core_utils_slist_free( filters );
 	g_free( old_text );
 
-	g_signal_emit_by_name( G_OBJECT( data->window ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, context, FALSE );
+	g_signal_emit_by_name( G_OBJECT( data->window ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, context, 0 );
 }
 
 static gboolean
@@ -537,21 +540,25 @@ on_key_pressed_event( GtkWidget *widget, GdkEventKey *event, MatchListStr *data
 
 	stop = FALSE;
 
-	if( event->keyval == GDK_F2 ){
+	if( event->keyval == NACT_KEY_F2 ){
 		if( data->editable_filter ){
 			edit_inline( data );
 			stop = TRUE;
 		}
 	}
 
-	if( event->keyval == GDK_Insert || event->keyval == GDK_KP_Insert ){
-		insert_new_row( data );
-		stop = TRUE;
+	if( event->keyval == NACT_KEY_Insert || event->keyval == NACT_KEY_KP_Insert ){
+		if( data->editable_item ){
+			insert_new_row( data );
+			stop = TRUE;
+		}
 	}
 
-	if( event->keyval == GDK_Delete || event->keyval == GDK_KP_Delete ){
-		delete_current_row( data );
-		stop = TRUE;
+	if( event->keyval == NACT_KEY_Delete || event->keyval == NACT_KEY_KP_Delete ){
+		if( data->editable_item ){
+			delete_current_row( data );
+			stop = TRUE;
+		}
 	}
 
 	return( stop );
@@ -579,32 +586,41 @@ on_must_match_toggled( GtkCellRendererToggle *cell_renderer, gchar *path_str, Ma
 	NAIContext *context;
 	GSList *filters;
 	gchar *to_remove;
+	gboolean active;
 
 	/*gboolean is_active = gtk_cell_renderer_toggle_get_active( cell_renderer );
 	g_debug( "%s: is_active=%s", thisfn, is_active ? "True":"False" );*/
 
-	if( !gtk_cell_renderer_toggle_get_active( cell_renderer )){
-		context = nact_main_tab_get_context( NACT_MAIN_WINDOW( data->window ), NULL );
-		g_return_if_fail( NA_IS_ICONTEXT( context ));
+	active = gtk_cell_renderer_toggle_get_active( cell_renderer );
 
-		set_match_status( path_str, TRUE, FALSE, data );
+	if( data->editable_item ){
+		if( !active ){
+			g_object_get( G_OBJECT( data->window ), MAIN_PROP_CONTEXT, &context, NULL );
+			g_return_if_fail( NA_IS_ICONTEXT( context ));
 
-		filter = get_filter_from_path( path_str, data );
-		filters = ( *data->pget )( context );
+			set_match_status( path_str, TRUE, FALSE, data );
 
-		if( filters ){
-			to_remove = g_strdup_printf( "!%s", filter );
-			filters = na_core_utils_slist_remove_ascii( filters, to_remove );
-			g_free( to_remove );
+			filter = get_filter_from_path( path_str, data );
+			filters = ( *data->pget )( context );
+
+			if( filters ){
+				to_remove = g_strdup_printf( "!%s", filter );
+				filters = na_core_utils_slist_remove_ascii( filters, to_remove );
+				g_free( to_remove );
+			}
+
+			filters = g_slist_prepend( filters, g_strdup( filter ));
+			( *data->pset )( context, filters );
+
+			na_core_utils_slist_free( filters );
+			g_free( filter );
+
+			g_signal_emit_by_name( G_OBJECT( data->window ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, context, 0 );
 		}
-
-		filters = g_slist_prepend( filters, g_strdup( filter ));
-		( *data->pset )( context, filters );
-
-		na_core_utils_slist_free( filters );
-		g_free( filter );
-
-		g_signal_emit_by_name( G_OBJECT( data->window ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, context, FALSE );
+	} else {
+		g_signal_handlers_block_by_func(( gpointer ) cell_renderer, on_must_match_toggled, data );
+		gtk_cell_renderer_toggle_set_active( cell_renderer, !active );
+		g_signal_handlers_unblock_by_func(( gpointer ) cell_renderer, on_must_match_toggled, data );
 	}
 }
 
@@ -622,31 +638,40 @@ on_must_not_match_toggled( GtkCellRendererToggle *cell_renderer, gchar *path_str
 	NAIContext *context;
 	GSList *filters;
 	gchar *to_add;
+	gboolean active;
 
 	/*gboolean is_active = gtk_cell_renderer_toggle_get_active( cell_renderer );
 	g_debug( "%s: is_active=%s", thisfn, is_active ? "True":"False" );*/
 
-	if( !gtk_cell_renderer_toggle_get_active( cell_renderer )){
-		context = nact_main_tab_get_context( NACT_MAIN_WINDOW( data->window ), NULL );
-		g_return_if_fail( NA_IS_ICONTEXT( context ));
+	active = gtk_cell_renderer_toggle_get_active( cell_renderer );
 
-		set_match_status( path_str, FALSE, TRUE, data );
+	if( data->editable_item ){
+		if( !active ){
+			g_object_get( G_OBJECT( data->window ), MAIN_PROP_CONTEXT, &context, NULL );
+			g_return_if_fail( NA_IS_ICONTEXT( context ));
 
-		filter = get_filter_from_path( path_str, data );
-		filters = ( *data->pget )( context );
+			set_match_status( path_str, FALSE, TRUE, data );
 
-		if( filters ){
-			filters = na_core_utils_slist_remove_ascii( filters, filter );
+			filter = get_filter_from_path( path_str, data );
+			filters = ( *data->pget )( context );
+
+			if( filters ){
+				filters = na_core_utils_slist_remove_ascii( filters, filter );
+			}
+
+			to_add = g_strdup_printf( "!%s", filter );
+			filters = g_slist_prepend( filters, to_add );
+			( *data->pset )( context, filters );
+
+			na_core_utils_slist_free( filters );
+			g_free( filter );
+
+			g_signal_emit_by_name( G_OBJECT( data->window ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, context, 0 );
 		}
-
-		to_add = g_strdup_printf( "!%s", filter );
-		filters = g_slist_prepend( filters, to_add );
-		( *data->pset )( context, filters );
-
-		na_core_utils_slist_free( filters );
-		g_free( filter );
-
-		g_signal_emit_by_name( G_OBJECT( data->window ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, context, FALSE );
+	} else {
+		g_signal_handlers_block_by_func(( gpointer ) cell_renderer, on_must_not_match_toggled, data );
+		gtk_cell_renderer_toggle_set_active( cell_renderer, !active );
+		g_signal_handlers_unblock_by_func(( gpointer ) cell_renderer, on_must_not_match_toggled, data );
 	}
 }
 
@@ -670,7 +695,7 @@ add_filter( MatchListStr *data, const gchar *filter, const gchar *prefix )
 	GSList *filters;
 	gchar *to_add;
 
-	context = nact_main_tab_get_context( NACT_MAIN_WINDOW( data->window ), NULL );
+	g_object_get( G_OBJECT( data->window ), MAIN_PROP_CONTEXT, &context, NULL );
 
 	if( context ){
 		filters = ( *data->pget )( context );
@@ -679,7 +704,7 @@ add_filter( MatchListStr *data, const gchar *filter, const gchar *prefix )
 		( *data->pset )( context, filters );
 		na_core_utils_slist_free( filters );
 
-		g_signal_emit_by_name( G_OBJECT( data->window ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, context, FALSE );
+		g_signal_emit_by_name( G_OBJECT( data->window ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, context, 0 );
 	}
 }
 
@@ -723,7 +748,7 @@ delete_current_row( MatchListStr *data )
 
 		delete_row_at_path( data->listview, model, path );
 
-		context = nact_main_tab_get_context( NACT_MAIN_WINDOW( data->window ), NULL );
+		g_object_get( G_OBJECT( data->window ), MAIN_PROP_CONTEXT, &context, NULL );
 
 		if( context ){
 			filters = ( *data->pget )( context );
@@ -736,7 +761,7 @@ delete_current_row( MatchListStr *data )
 				( *data->pset )( context, filters );
 				na_core_utils_slist_free( filters );
 
-				g_signal_emit_by_name( G_OBJECT( data->window ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, context, FALSE );
+				g_signal_emit_by_name( G_OBJECT( data->window ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, context, 0 );
 			}
 		}
 
@@ -824,7 +849,7 @@ get_must_match_header( guint id )
 
 	for( i = 0 ; st_match_headers[i].header_id ; ++i ){
 		if( st_match_headers[i].header_id == id ){
-			return( st_match_headers[i].header_label );
+			return( gettext( st_match_headers[i].header_label ));
 		}
 	}
 
@@ -849,7 +874,7 @@ insert_new_row( MatchListStr *data )
 	static const gchar *filter_label = N_( "new-filter" );
 	gchar *label;
 
-	label = search_for_unique_label( filter_label, data );
+	label = search_for_unique_label( gettext( filter_label ), data );
 	insert_new_row_data( data, label, FALSE, FALSE );
 	g_free( label );
 }
