@@ -32,8 +32,8 @@
 #include <config.h>
 #endif
 
-#include <gconf/gconf-client.h>
 #include <glib/gi18n.h>
+#include <libintl.h>
 #include <string.h>
 
 #include <api/na-core-utils.h>
@@ -45,14 +45,11 @@
 
 #include "nact-application.h"
 #include "nact-clipboard.h"
-#include "nact-iactions-list.h"
-#include "nact-iprefs.h"
-#include "nact-main-menubar-edit.h"
 #include "nact-main-statusbar.h"
 #include "nact-main-window.h"
 #include "nact-tree-model.h"
-#include "nact-tree-model-dnd.h"
 #include "nact-tree-model-priv.h"
+#include "nact-tree-ieditable.h"
 
 /*
  * call once egg_tree_multi_drag_add_drag_support( treeview ) at init time (before gtk_main)
@@ -130,7 +127,7 @@ static void          drop_inside_move_dest( NactTreeModel *model, GList *rows, G
 static gboolean      drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selection_data );
 static NAObjectItem *is_dropped_already_exists( const NAObjectItem *importing, const NactMainWindow *window );
 static char         *get_xds_atom_value( GdkDragContext *context );
-static gboolean      is_parent_accept_new_childs( NactApplication *application, NactMainWindow *window, NAObjectItem *parent );
+static gboolean      is_parent_accept_new_children( NactApplication *application, NactMainWindow *window, NAObjectItem *parent );
 static guint         target_atom_to_id( GdkAtom atom );
 
 /**
@@ -260,12 +257,12 @@ nact_tree_model_dnd_idrag_dest_row_drop_possible( GtkTreeDragDest *drag_dest, Gt
 /**
  * nact_tree_model_dnd_imulti_drag_source_drag_data_get:
  * @context: contains
- *  - the suggested action, as choosen by the drop site,
+ *  - the suggested action, as chosen by the drop site,
  *    between those we have provided in imulti_drag_source_get_drag_actions()
  *  - the target folder (XDS protocol)
  * @selection_data:
  * @rows: list of row references which are to be dropped
- * @info: the suggested format, as choosen by the drop site, between those
+ * @info: the suggested format, as chosen by the drop site, between those
  *  we have provided in imulti_drag_source_get_target_list()
  *
  * This function is called when we release the selected items onto the
@@ -459,7 +456,7 @@ nact_tree_model_dnd_imulti_drag_source_row_draggable( EggTreeMultiDragSource *dr
 
 			path = gtk_tree_row_reference_get_path(( GtkTreeRowReference * ) it->data );
 			gtk_tree_model_get_iter( store, &iter, path );
-			gtk_tree_model_get( store, &iter, IACTIONS_LIST_NAOBJECT_COLUMN, &object, -1 );
+			gtk_tree_model_get( store, &iter, TREE_COLUMN_NAOBJECT, &object, -1 );
 
 			if( NA_IS_OBJECT_PROFILE( object )){
 				model->private->drag_has_profiles = TRUE;
@@ -554,17 +551,6 @@ nact_tree_model_dnd_on_drag_end( GtkWidget *widget, GdkDragContext *context, Bas
  *
  * Returns: %TRUE if the specified rows were successfully inserted at
  * the given dest, %FALSE else.
- *
- * The dest path is computed based on the current appearance of the list
- * Drop should so occurs inside an inchanged list to keep a valid path
- * in the case of a move, this leads to :
- *  1) marks dragged items as 'to be deleted'
- *  2) insert new dropped items
- *  3) remove 'to be deleted' items
- * -> not an easy idea as we want modify the id of all the dragged
- *    hierarchy
- *
- * adjusting the path: quid if the target dest is not at the same level
  */
 static gboolean
 drop_inside( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selection_data )
@@ -584,10 +570,14 @@ drop_inside( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selecti
 	GtkTreeIter iter;
 	GList *deletable;
 	gboolean relabel;
+	NactTreeView *items_view;
 
 	application = NACT_APPLICATION( base_window_get_application( model->private->window ));
 	updater = nact_application_get_updater( application );
-	main_window = NACT_MAIN_WINDOW( base_application_get_main_window( BASE_APPLICATION( application )));
+
+	g_return_val_if_fail( NACT_IS_MAIN_WINDOW( model->private->window ), FALSE );
+	main_window = NACT_MAIN_WINDOW( model->private->window );
+	items_view = nact_main_window_get_items_view( main_window );
 
 	/*
 	 * NACT format (may embed profiles, or not)
@@ -612,22 +602,23 @@ drop_inside( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selecti
 		path = gtk_tree_row_reference_get_path(( GtkTreeRowReference * ) it->data );
 		if( path ){
 			if( gtk_tree_model_get_iter( GTK_TREE_MODEL( model ), &iter, path )){
-				gtk_tree_model_get( GTK_TREE_MODEL( model ), &iter, IACTIONS_LIST_NAOBJECT_COLUMN, &current, -1 );
+				gtk_tree_model_get( GTK_TREE_MODEL( model ), &iter, TREE_COLUMN_NAOBJECT, &current, -1 );
 				g_object_unref( current );
 
 				if( copy_data ){
 					inserted = ( NAObject * ) na_object_duplicate( current );
 					na_object_set_origin( inserted, NULL );
 					na_object_check_status( inserted );
+					relabel = na_updater_should_pasted_be_relabeled( updater, inserted );
 
 				} else {
 					inserted = na_object_ref( current );
 					deletable = g_list_prepend( NULL, inserted );
-					nact_iactions_list_bis_delete( NACT_IACTIONS_LIST( main_window ), deletable, FALSE );
+					nact_tree_ieditable_delete( NACT_TREE_IEDITABLE( items_view ), deletable, TREE_OPE_MOVE );
 					g_list_free( deletable );
+					relabel = FALSE;
 				}
 
-				relabel = nact_main_menubar_edit_is_pasted_object_relabeled( inserted, NA_PIVOT( updater ));
 				na_object_prepare_for_paste( inserted, relabel, copy_data, parent );
 				object_list = g_list_prepend( object_list, inserted );
 				g_debug( "%s: dropped=%s", thisfn, na_object_get_label( inserted ));
@@ -637,14 +628,9 @@ drop_inside( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selecti
 	}
 	object_list = g_list_reverse( object_list );
 
-	nact_iactions_list_bis_insert_at_path( NACT_IACTIONS_LIST( main_window ), object_list, new_dest );
+	nact_tree_ieditable_insert_at_path( NACT_TREE_IEDITABLE( items_view ), object_list, new_dest );
 
-	if( gtk_tree_path_get_depth( new_dest ) == 1 ){
-		g_signal_emit_by_name( main_window, MAIN_WINDOW_SIGNAL_LEVEL_ZERO_ORDER_CHANGED, GINT_TO_POINTER( TRUE ));
-	}
-
-	g_list_foreach( object_list, ( GFunc ) na_object_object_unref, NULL );
-	g_list_free( object_list );
+	na_object_free_items( object_list );
 	gtk_tree_path_free( new_dest );
 
 	g_list_foreach( rows, ( GFunc ) gtk_tree_row_reference_free, NULL );
@@ -678,7 +664,9 @@ is_drop_possible( NactTreeModel *model, GtkTreePath *dest, NAObjectItem **parent
 	drop_ok = FALSE;
 	parent_dest = NULL;
 	application = NACT_APPLICATION( base_window_get_application( model->private->window ));
-	main_window = NACT_MAIN_WINDOW( base_application_get_main_window( BASE_APPLICATION( application )));
+
+	g_return_val_if_fail( NACT_IS_MAIN_WINDOW( model->private->window ), FALSE );
+	main_window = NACT_MAIN_WINDOW( model->private->window );
 
 	/* if we can have an iter on given dest, then the dest already exists
 	 * so dropped items should be of the same type that already existing
@@ -693,7 +681,7 @@ is_drop_possible( NactTreeModel *model, GtkTreePath *dest, NAObjectItem **parent
 
 		if( model->private->drag_has_profiles ){
 			nact_main_statusbar_display_with_timeout(
-						main_window, TREE_MODEL_STATUSBAR_CONTEXT, st_refuse_drop_profile );
+						main_window, TREE_MODEL_STATUSBAR_CONTEXT, gettext( st_refuse_drop_profile ));
 
 		} else {
 			drop_ok = TRUE;
@@ -708,7 +696,7 @@ is_drop_possible( NactTreeModel *model, GtkTreePath *dest, NAObjectItem **parent
 	}
 
 	if( drop_ok ){
-		drop_ok = is_parent_accept_new_childs( application, main_window, parent_dest );
+		drop_ok = is_parent_accept_new_children( application, main_window, parent_dest );
 	}
 
 	if( drop_ok && parent ){
@@ -728,7 +716,7 @@ is_drop_possible_before_iter( NactTreeModel *model, GtkTreeIter *iter, NactMainW
 	drop_ok = FALSE;
 	*parent = NULL;
 
-	gtk_tree_model_get( GTK_TREE_MODEL( model ), iter, IACTIONS_LIST_NAOBJECT_COLUMN, &object, -1 );
+	gtk_tree_model_get( GTK_TREE_MODEL( model ), iter, TREE_COLUMN_NAOBJECT, &object, -1 );
 	g_object_unref( object );
 	g_debug( "%s: current object at dest is %s", thisfn, G_OBJECT_TYPE_NAME( object ));
 
@@ -741,7 +729,7 @@ is_drop_possible_before_iter( NactTreeModel *model, GtkTreeIter *iter, NactMainW
 		} else {
 			/* unable to drop a profile here */
 			nact_main_statusbar_display_with_timeout(
-					window, TREE_MODEL_STATUSBAR_CONTEXT, st_refuse_drop_profile );
+					window, TREE_MODEL_STATUSBAR_CONTEXT, gettext( st_refuse_drop_profile ));
 		}
 
 	} else if( NA_IS_OBJECT_ITEM( object )){
@@ -751,7 +739,7 @@ is_drop_possible_before_iter( NactTreeModel *model, GtkTreeIter *iter, NactMainW
 	} else {
 		/* unable to drop an action or a menu here */
 		nact_main_statusbar_display_with_timeout(
-				window, TREE_MODEL_STATUSBAR_CONTEXT, st_refuse_drop_item );
+				window, TREE_MODEL_STATUSBAR_CONTEXT, gettext( st_refuse_drop_item ));
 	}
 
 	return( drop_ok );
@@ -773,7 +761,7 @@ is_drop_possible_into_dest( NactTreeModel *model, GtkTreePath *dest, NactMainWin
 
 	if( gtk_tree_path_up( path )){
 		if( gtk_tree_model_get_iter( GTK_TREE_MODEL( model ), &iter, path )){
-			gtk_tree_model_get( GTK_TREE_MODEL( model ), &iter, IACTIONS_LIST_NAOBJECT_COLUMN, &object, -1 );
+			gtk_tree_model_get( GTK_TREE_MODEL( model ), &iter, TREE_COLUMN_NAOBJECT, &object, -1 );
 			g_object_unref( object );
 			g_debug( "%s: current object at parent dest is %s", thisfn, G_OBJECT_TYPE_NAME( object ));
 
@@ -785,7 +773,7 @@ is_drop_possible_into_dest( NactTreeModel *model, GtkTreePath *dest, NactMainWin
 
 				} else {
 					nact_main_statusbar_display_with_timeout(
-							window, TREE_MODEL_STATUSBAR_CONTEXT, st_refuse_drop_profile );
+							window, TREE_MODEL_STATUSBAR_CONTEXT, gettext( st_refuse_drop_profile ));
 				}
 
 			} else if( NA_IS_OBJECT_MENU( object )){
@@ -794,7 +782,7 @@ is_drop_possible_into_dest( NactTreeModel *model, GtkTreePath *dest, NactMainWin
 
 			} else {
 				nact_main_statusbar_display_with_timeout(
-						window, TREE_MODEL_STATUSBAR_CONTEXT, st_refuse_drop_item );
+						window, TREE_MODEL_STATUSBAR_CONTEXT, gettext( st_refuse_drop_item ));
 			}
 		}
 	}
@@ -862,13 +850,13 @@ drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
 	NAUpdater *updater;
 	NactMainWindow *main_window;
 	NAImporterParms parms;
-	GConfClient *gconf;
 	GList *it;
 	guint count;
 	GString *str;
 	GSList *im;
 	GList *imported;
 	const gchar *selection_data_data;
+	NactTreeView *view;
 
 	gchar *dest_str = gtk_tree_path_to_string( dest );
 	g_debug( "%s: model=%p, dest=%p (%s), selection_data=%p",
@@ -884,7 +872,9 @@ drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
 
 	application = NACT_APPLICATION( base_window_get_application( model->private->window ));
 	updater = nact_application_get_updater( application );
-	main_window = NACT_MAIN_WINDOW( base_application_get_main_window( BASE_APPLICATION( application )));
+
+	g_return_val_if_fail( NACT_IS_MAIN_WINDOW( model->private->window ), FALSE );
+	main_window = NACT_MAIN_WINDOW( model->private->window );
 
 #if GTK_CHECK_VERSION( 2, 14, 0 )
 	selection_data_data = ( const gchar * ) gtk_selection_data_get_data( selection_data );
@@ -893,12 +883,10 @@ drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
 #endif
 	g_debug( "%s", selection_data_data );
 
-	parms.parent = base_window_get_toplevel( BASE_WINDOW( main_window ));
+	parms.parent = base_window_get_gtk_toplevel( BASE_WINDOW( main_window ));
 	parms.uris = g_slist_reverse( na_core_utils_slist_from_split( selection_data_data, "\r\n" ));
 
-	gconf = gconf_client_get_default();
-	parms.mode = na_iprefs_get_import_mode( gconf, IPREFS_IMPORT_ITEMS_IMPORT_MODE );
-	g_object_unref( gconf );
+	parms.mode = na_iprefs_get_import_mode( NA_IPREFS_IMPORT_PREFERRED_MODE, NULL );
 
 	parms.check_fn = ( NAIImporterCheckFn ) is_dropped_already_exists;
 	parms.check_fn_data = main_window;
@@ -933,6 +921,7 @@ drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
 
 		if( result->imported ){
 			imported = g_list_prepend( imported, result->imported );
+			na_updater_check_item_writability_status( updater, result->imported );
 		}
 	}
 
@@ -948,18 +937,16 @@ drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
 
 	g_string_free( str, TRUE );
 
-	/* check status of newly imported items, and insert them in the list view
+	/* insert newly imported items in the list view
 	 */
-	for( it = imported ; it ; it = it->next ){
-		na_object_check_status( it->data );
-		na_object_dump( it->data );
-		drop_done = TRUE;
+	if( imported ){
+		na_object_dump_tree( imported );
+		view = nact_main_window_get_items_view( main_window );
+		nact_tree_ieditable_insert_at_path( NACT_TREE_IEDITABLE( view ), imported, dest );
 	}
 
-	nact_iactions_list_bis_insert_at_path( NACT_IACTIONS_LIST( main_window ), imported, dest );
-	nact_tree_model_dump( model );
-
-	na_object_unref_items( imported );
+	drop_done = TRUE;
+	na_object_free_items( imported );
 	na_core_utils_slist_free( parms.uris );
 
 	for( it = parms.results ; it ; it = it->next ){
@@ -973,8 +960,11 @@ drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
 static NAObjectItem *
 is_dropped_already_exists( const NAObjectItem *importing, const NactMainWindow *window )
 {
+	NactTreeView *items_view;
+
 	gchar *id = na_object_get_id( importing );
-	NAObjectItem *exists = nact_main_window_get_item( window, id );
+	items_view = nact_main_window_get_items_view( window );
+	NAObjectItem *exists = nact_tree_view_get_item_by_id( items_view, id );
 	g_free( id );
 
 	return( exists );
@@ -1127,7 +1117,7 @@ get_xds_atom_value( GdkDragContext *context )
  * to register the new child
  */
 static gboolean
-is_parent_accept_new_childs( NactApplication *application, NactMainWindow *window, NAObjectItem *parent )
+is_parent_accept_new_children( NactApplication *application, NactMainWindow *window, NAObjectItem *parent )
 {
 	gboolean accept_ok;
 	NAUpdater *updater;
@@ -1139,23 +1129,22 @@ is_parent_accept_new_childs( NactApplication *application, NactMainWindow *windo
 	 * ensure that level zero is writable
 	 */
 	if( parent == NULL ){
-
-		if( na_pivot_is_level_zero_writable( NA_PIVOT( updater ))){
+		if( na_updater_is_level_zero_writable( updater )){
 			accept_ok = TRUE;
 
 		} else {
 			nact_main_statusbar_display_with_timeout(
-						window, TREE_MODEL_STATUSBAR_CONTEXT, st_level_zero_not_writable );
+						window, TREE_MODEL_STATUSBAR_CONTEXT, gettext( st_level_zero_not_writable ));
 		}
 
 	/* see if the parent is writable
 	 */
-	} else if( na_updater_is_item_writable( updater, parent, NULL )){
+	} else if( na_object_is_finally_writable( parent, NULL )){
 		accept_ok = TRUE;
 
 	} else {
 			nact_main_statusbar_display_with_timeout(
-						window, TREE_MODEL_STATUSBAR_CONTEXT, st_parent_not_writable );
+						window, TREE_MODEL_STATUSBAR_CONTEXT, gettext( st_parent_not_writable ));
 	}
 
 	return( accept_ok );
